@@ -24,6 +24,7 @@ from .paginator import (
     ListBillingGroupCostReportsPaginator,
     ListBillingGroupsPaginator,
     ListCustomLineItemsPaginator,
+    ListCustomLineItemVersionsPaginator,
     ListPricingPlansAssociatedWithPricingRulePaginator,
     ListPricingPlansPaginator,
     ListPricingRulesAssociatedToPricingPlanPaginator,
@@ -57,6 +58,8 @@ from .type_defs import (
     ListBillingGroupsOutputTypeDef,
     ListCustomLineItemsFilterTypeDef,
     ListCustomLineItemsOutputTypeDef,
+    ListCustomLineItemVersionsFilterTypeDef,
+    ListCustomLineItemVersionsOutputTypeDef,
     ListPricingPlansAssociatedWithPricingRuleOutputTypeDef,
     ListPricingPlansFilterTypeDef,
     ListPricingPlansOutputTypeDef,
@@ -288,7 +291,8 @@ class BillingConductorClient(BaseClient):
 
     def delete_pricing_rule(self, *, Arn: str) -> DeletePricingRuleOutputTypeDef:
         """
-        Deletes the pricing rule identified by the input Amazon Resource Name (ARN).
+        Deletes the pricing rule that's identified by the input Amazon Resource Name
+        (ARN).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.delete_pricing_rule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#delete_pricing_rule)
@@ -336,8 +340,8 @@ class BillingConductorClient(BaseClient):
         NextToken: str = ...
     ) -> ListAccountAssociationsOutputTypeDef:
         """
-        * **Amazon Web Services Billing Conductor is in beta release and is subject to
-        change.
+        This is a paginated call to list linked accounts that are linked to the payer
+        account for the specified time period.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.list_account_associations)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_account_associations)
@@ -376,6 +380,21 @@ class BillingConductorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_billing_groups)
         """
 
+    def list_custom_line_item_versions(
+        self,
+        *,
+        Arn: str,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        Filters: ListCustomLineItemVersionsFilterTypeDef = ...
+    ) -> ListCustomLineItemVersionsOutputTypeDef:
+        """
+        A paginated call to get a list of all custom line item versions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.list_custom_line_item_versions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_custom_line_item_versions)
+        """
+
     def list_custom_line_items(
         self,
         *,
@@ -416,7 +435,7 @@ class BillingConductorClient(BaseClient):
         NextToken: str = ...
     ) -> ListPricingPlansAssociatedWithPricingRuleOutputTypeDef:
         """
-        A list of the pricing plans associated with a pricing rule.
+        A list of the pricing plans that are associated with a pricing rule.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.list_pricing_plans_associated_with_pricing_rule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_pricing_plans_associated_with_pricing_rule)
@@ -447,7 +466,7 @@ class BillingConductorClient(BaseClient):
         NextToken: str = ...
     ) -> ListPricingRulesAssociatedToPricingPlanOutputTypeDef:
         """
-        Lists the pricing rules associated with a pricing plan.
+        Lists the pricing rules that are associated with a pricing plan.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.list_pricing_rules_associated_to_pricing_plan)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_pricing_rules_associated_to_pricing_plan)
@@ -463,7 +482,7 @@ class BillingConductorClient(BaseClient):
         Filters: ListResourcesAssociatedToCustomLineItemFilterTypeDef = ...
     ) -> ListResourcesAssociatedToCustomLineItemOutputTypeDef:
         """
-        List the resources associated to a custom line item.
+        List the resources that are associated to a custom line item.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.list_resources_associated_to_custom_line_item)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#list_resources_associated_to_custom_line_item)
@@ -578,6 +597,15 @@ class BillingConductorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_custom_line_item_versions"]
+    ) -> ListCustomLineItemVersionsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/billingconductor.html#BillingConductor.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_billingconductor/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_custom_line_items"]
