@@ -28,6 +28,7 @@ __all__ = (
     "ListAccountAssociationsPaginatorName",
     "ListBillingGroupCostReportsPaginatorName",
     "ListBillingGroupsPaginatorName",
+    "ListCustomLineItemVersionsPaginatorName",
     "ListCustomLineItemsPaginatorName",
     "ListPricingPlansAssociatedWithPricingRulePaginatorName",
     "ListPricingPlansPaginatorName",
@@ -44,7 +45,11 @@ __all__ = (
 
 
 AssociateResourceErrorReasonType = Literal[
-    "ILLEGAL_CUSTOMLINEITEM", "INTERNAL_SERVER_EXCEPTION", "INVALID_ARN", "SERVICE_LIMIT_EXCEEDED"
+    "ILLEGAL_CUSTOMLINEITEM",
+    "INTERNAL_SERVER_EXCEPTION",
+    "INVALID_ARN",
+    "INVALID_BILLING_PERIOD_RANGE",
+    "SERVICE_LIMIT_EXCEEDED",
 ]
 BillingGroupStatusType = Literal["ACTIVE", "PRIMARY_ACCOUNT_MISSING"]
 CurrencyCodeType = Literal["CNY", "USD"]
@@ -53,6 +58,7 @@ CustomLineItemTypeType = Literal["CREDIT", "FEE"]
 ListAccountAssociationsPaginatorName = Literal["list_account_associations"]
 ListBillingGroupCostReportsPaginatorName = Literal["list_billing_group_cost_reports"]
 ListBillingGroupsPaginatorName = Literal["list_billing_groups"]
+ListCustomLineItemVersionsPaginatorName = Literal["list_custom_line_item_versions"]
 ListCustomLineItemsPaginatorName = Literal["list_custom_line_items"]
 ListPricingPlansAssociatedWithPricingRulePaginatorName = Literal[
     "list_pricing_plans_associated_with_pricing_rule"
@@ -316,6 +322,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -404,6 +411,7 @@ PaginatorName = Literal[
     "list_account_associations",
     "list_billing_group_cost_reports",
     "list_billing_groups",
+    "list_custom_line_item_versions",
     "list_custom_line_items",
     "list_pricing_plans",
     "list_pricing_plans_associated_with_pricing_rule",
