@@ -55,6 +55,7 @@ __all__ = (
     "ListBillingGroupsFilterTypeDef",
     "ListCustomLineItemFlatChargeDetailsTypeDef",
     "ListCustomLineItemPercentageChargeDetailsTypeDef",
+    "ListCustomLineItemVersionsBillingPeriodRangeFilterTypeDef",
     "ListCustomLineItemsFilterTypeDef",
     "ListPricingPlansAssociatedWithPricingRuleInputRequestTypeDef",
     "ListPricingPlansFilterTypeDef",
@@ -109,6 +110,7 @@ __all__ = (
     "ListBillingGroupsInputListBillingGroupsPaginateTypeDef",
     "ListBillingGroupsInputRequestTypeDef",
     "ListCustomLineItemChargeDetailsTypeDef",
+    "ListCustomLineItemVersionsFilterTypeDef",
     "ListCustomLineItemsInputListCustomLineItemsPaginateTypeDef",
     "ListCustomLineItemsInputRequestTypeDef",
     "ListPricingPlansInputListPricingPlansPaginateTypeDef",
@@ -126,9 +128,13 @@ __all__ = (
     "ListBillingGroupsOutputTypeDef",
     "CreateCustomLineItemInputRequestTypeDef",
     "CustomLineItemListElementTypeDef",
+    "CustomLineItemVersionListElementTypeDef",
     "UpdateCustomLineItemOutputTypeDef",
+    "ListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef",
+    "ListCustomLineItemVersionsInputRequestTypeDef",
     "UpdateCustomLineItemInputRequestTypeDef",
     "ListCustomLineItemsOutputTypeDef",
+    "ListCustomLineItemVersionsOutputTypeDef",
 )
 
 AccountAssociationsListElementTypeDef = TypedDict(
@@ -185,13 +191,27 @@ AssociateResourceErrorTypeDef = TypedDict(
     total=False,
 )
 
-CustomLineItemBillingPeriodRangeTypeDef = TypedDict(
-    "CustomLineItemBillingPeriodRangeTypeDef",
+_RequiredCustomLineItemBillingPeriodRangeTypeDef = TypedDict(
+    "_RequiredCustomLineItemBillingPeriodRangeTypeDef",
     {
         "InclusiveStartBillingPeriod": str,
-        "ExclusiveEndBillingPeriod": str,
     },
 )
+_OptionalCustomLineItemBillingPeriodRangeTypeDef = TypedDict(
+    "_OptionalCustomLineItemBillingPeriodRangeTypeDef",
+    {
+        "ExclusiveEndBillingPeriod": str,
+    },
+    total=False,
+)
+
+
+class CustomLineItemBillingPeriodRangeTypeDef(
+    _RequiredCustomLineItemBillingPeriodRangeTypeDef,
+    _OptionalCustomLineItemBillingPeriodRangeTypeDef,
+):
+    pass
+
 
 BillingGroupCostReportElementTypeDef = TypedDict(
     "BillingGroupCostReportElementTypeDef",
@@ -380,6 +400,15 @@ ListCustomLineItemPercentageChargeDetailsTypeDef = TypedDict(
     },
 )
 
+ListCustomLineItemVersionsBillingPeriodRangeFilterTypeDef = TypedDict(
+    "ListCustomLineItemVersionsBillingPeriodRangeFilterTypeDef",
+    {
+        "StartBillingPeriod": str,
+        "EndBillingPeriod": str,
+    },
+    total=False,
+)
+
 ListCustomLineItemsFilterTypeDef = TypedDict(
     "ListCustomLineItemsFilterTypeDef",
     {
@@ -497,6 +526,7 @@ ListResourcesAssociatedToCustomLineItemResponseElementTypeDef = TypedDict(
     {
         "Arn": str,
         "Relationship": CustomLineItemRelationshipType,
+        "EndBillingPeriod": str,
     },
     total=False,
 )
@@ -1077,6 +1107,14 @@ class ListCustomLineItemChargeDetailsTypeDef(
     pass
 
 
+ListCustomLineItemVersionsFilterTypeDef = TypedDict(
+    "ListCustomLineItemVersionsFilterTypeDef",
+    {
+        "BillingPeriodRange": ListCustomLineItemVersionsBillingPeriodRangeFilterTypeDef,
+    },
+    total=False,
+)
+
 ListCustomLineItemsInputListCustomLineItemsPaginateTypeDef = TypedDict(
     "ListCustomLineItemsInputListCustomLineItemsPaginateTypeDef",
     {
@@ -1299,6 +1337,24 @@ CustomLineItemListElementTypeDef = TypedDict(
     total=False,
 )
 
+CustomLineItemVersionListElementTypeDef = TypedDict(
+    "CustomLineItemVersionListElementTypeDef",
+    {
+        "Name": str,
+        "ChargeDetails": ListCustomLineItemChargeDetailsTypeDef,
+        "CurrencyCode": CurrencyCodeType,
+        "Description": str,
+        "ProductCode": str,
+        "BillingGroupArn": str,
+        "CreationTime": int,
+        "LastModifiedTime": int,
+        "AssociationSize": int,
+        "StartBillingPeriod": str,
+        "EndBillingPeriod": str,
+    },
+    total=False,
+)
+
 UpdateCustomLineItemOutputTypeDef = TypedDict(
     "UpdateCustomLineItemOutputTypeDef",
     {
@@ -1313,6 +1369,53 @@ UpdateCustomLineItemOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef = TypedDict(
+    "_RequiredListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef = TypedDict(
+    "_OptionalListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef",
+    {
+        "Filters": ListCustomLineItemVersionsFilterTypeDef,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef(
+    _RequiredListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef,
+    _OptionalListCustomLineItemVersionsInputListCustomLineItemVersionsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListCustomLineItemVersionsInputRequestTypeDef = TypedDict(
+    "_RequiredListCustomLineItemVersionsInputRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalListCustomLineItemVersionsInputRequestTypeDef = TypedDict(
+    "_OptionalListCustomLineItemVersionsInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "Filters": ListCustomLineItemVersionsFilterTypeDef,
+    },
+    total=False,
+)
+
+
+class ListCustomLineItemVersionsInputRequestTypeDef(
+    _RequiredListCustomLineItemVersionsInputRequestTypeDef,
+    _OptionalListCustomLineItemVersionsInputRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateCustomLineItemInputRequestTypeDef = TypedDict(
     "_RequiredUpdateCustomLineItemInputRequestTypeDef",
     {
@@ -1346,3 +1449,12 @@ ListCustomLineItemsOutputTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+ListCustomLineItemVersionsOutputTypeDef = TypedDict(
+    "ListCustomLineItemVersionsOutputTypeDef",
+    {
+        "CustomLineItemVersions": List[CustomLineItemVersionListElementTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
